[nautilus-actions/file-manager-actions] NACTApplication class is renamed to FMAApplication



commit 6e594ec5207db230227560e35969640b8dd1a4da
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 19:20:34 2015 +0200

    NACTApplication class is renamed to FMAApplication

 src/ui/fma-add-capability-dialog.h |    8 +-
 src/ui/fma-add-scheme-dialog.h     |    4 +-
 src/ui/fma-application.c           |  136 ++++++++++++++++++------------------
 src/ui/fma-application.h           |   48 ++++++------
 src/ui/fma-assistant-export.c      |   12 ++--
 src/ui/fma-assistant-import.c      |    6 +-
 src/ui/main.c                      |    6 +-
 src/ui/nact-clipboard.c            |    6 +-
 src/ui/nact-export-ask.c           |    6 +-
 src/ui/nact-main-window-def.h      |    6 +-
 src/ui/nact-main-window.c          |   14 ++--
 src/ui/nact-main-window.h          |    2 +-
 src/ui/nact-menu.c                 |   16 ++--
 src/ui/nact-menu.h                 |    2 +-
 src/ui/nact-preferences-editor.c   |    6 +-
 src/ui/nact-providers-list.c       |   12 ++--
 src/ui/nact-schemes-list.c         |    6 +-
 src/ui/nact-sort-buttons.c         |    4 +-
 src/ui/nact-tree-ieditable.c       |    4 +-
 src/ui/nact-tree-model-dnd.c       |   20 +++---
 20 files changed, 162 insertions(+), 162 deletions(-)
---
diff --git a/src/ui/fma-add-capability-dialog.h b/src/ui/fma-add-capability-dialog.h
index af2c854..6767119 100644
--- a/src/ui/fma-add-capability-dialog.h
+++ b/src/ui/fma-add-capability-dialog.h
@@ -51,20 +51,20 @@ G_BEGIN_DECLS
 #define FMA_IS_ADD_CAPABILITY_DIALOG_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), 
FMA_TYPE_ADD_CAPABILITY_DIALOG ))
 #define FMA_ADD_CAPABILITY_DIALOG_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), 
FMA_TYPE_ADD_CAPABILITY_DIALOG, FMAAddCapabilityDialogClass ))
 
-typedef struct _FMAAddCapabilityDialogPrivate        FMAAddCapabilityDialogPrivate;
+typedef struct _FMAAddCapabilityDialogPrivate         FMAAddCapabilityDialogPrivate;
 
 typedef struct {
        /*< private >*/
-       BaseDialog                      parent;
+       BaseDialog                     parent;
        FMAAddCapabilityDialogPrivate *private;
 }
        FMAAddCapabilityDialog;
 
-typedef struct _FMAAddCapabilityDialogClassPrivate   FMAAddCapabilityDialogClassPrivate;
+typedef struct _FMAAddCapabilityDialogClassPrivate    FMAAddCapabilityDialogClassPrivate;
 
 typedef struct {
        /*< private >*/
-       BaseDialogClass                      parent;
+       BaseDialogClass                     parent;
        FMAAddCapabilityDialogClassPrivate *private;
 }
        FMAAddCapabilityDialogClass;
diff --git a/src/ui/fma-add-scheme-dialog.h b/src/ui/fma-add-scheme-dialog.h
index f31b9d8..2e71c6b 100644
--- a/src/ui/fma-add-scheme-dialog.h
+++ b/src/ui/fma-add-scheme-dialog.h
@@ -55,14 +55,14 @@ typedef struct _FMAAddSchemeDialogPrivate         FMAAddSchemeDialogPrivate;
 
 typedef struct {
        /*< private >*/
-       BaseDialog                  parent;
+       BaseDialog                 parent;
        FMAAddSchemeDialogPrivate *private;
 }
        FMAAddSchemeDialog;
 
 typedef struct {
        /*< private >*/
-       BaseDialogClass             parent;
+       BaseDialogClass            parent;
 }
        FMAAddSchemeDialogClass;
 
diff --git a/src/ui/fma-assistant-export.c b/src/ui/fma-assistant-export.c
index b0d2c77..53380c6 100644
--- a/src/ui/fma-assistant-export.c
+++ b/src/ui/fma-assistant-export.c
@@ -200,15 +200,15 @@ static GList *
 ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container )
 {
        NactAssistantExport *window;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        GList *formats;
 
        g_return_val_if_fail( NACT_IS_ASSISTANT_EXPORT( instance ), NULL );
        window = NACT_ASSISTANT_EXPORT( instance );
 
-       application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+       updater = fma_application_get_updater( application );
        formats = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        return( formats );
@@ -754,7 +754,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        NactAssistantExport *window;
        GList *ia;
        ExportStruct *str;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        gboolean first;
 
@@ -764,8 +764,8 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 
        window = NACT_ASSISTANT_EXPORT( wnd );
 
-       application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+       updater = fma_application_get_updater( application );
        first = TRUE;
 
        g_return_if_fail( window->private->uri && strlen( window->private->uri ));
diff --git a/src/ui/fma-assistant-import.c b/src/ui/fma-assistant-import.c
index bcf55b2..7f249ac 100644
--- a/src/ui/fma-assistant-import.c
+++ b/src/ui/fma-assistant-import.c
@@ -648,7 +648,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        GList *import_results, *it;
        GList *insertable_items, *overriden_items;
        FMAImporterResult *result;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        NactTreeView *items_view;
 
@@ -657,8 +657,8 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        g_debug( "%s: window=%p, assistant=%p", thisfn, ( void * ) wnd, ( void * ) assistant );
        window = NACT_ASSISTANT_IMPORT( wnd );
        g_object_get( G_OBJECT( window ), BASE_PROP_MAIN_WINDOW, &main_window, NULL );
-       application = NACT_APPLICATION( base_window_get_application( main_window ));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( main_window ));
+       updater = fma_application_get_updater( application );
 
        memset( &importer_parms, '\0', sizeof( FMAImporterParms ));
        importer_parms.uris = gtk_file_chooser_get_uris( GTK_FILE_CHOOSER( window->private->file_chooser ));
diff --git a/src/ui/main.c b/src/ui/main.c
index 8ebca14..938c78a 100644
--- a/src/ui/main.c
+++ b/src/ui/main.c
@@ -53,7 +53,7 @@ static GLogFunc st_default_log_func = NULL;
 int
 main( int argc, char *argv[] )
 {
-       NactApplication *appli;
+       FMAApplication *appli;
        int ret;
 
        set_log_handler();
@@ -66,8 +66,8 @@ main( int argc, char *argv[] )
 
        /* create and run the application
         */
-       appli = nact_application_new();
-       ret = nact_application_run_with_args( appli, argc, argv );
+       appli = fma_application_new();
+       ret = fma_application_run_with_args( appli, argc, argv );
        g_object_unref( appli );
 
        return( ret );
diff --git a/src/ui/nact-clipboard.c b/src/ui/nact-clipboard.c
index 63deceb..b8b31b9 100644
--- a/src/ui/nact-clipboard.c
+++ b/src/ui/nact-clipboard.c
@@ -567,7 +567,7 @@ export_row_object( NactClipboard *clipboard, FMAObject *object, const gchar *des
 {
        static const gchar *thisfn = "nact_clipboard_export_row_object";
        GList *subitems, *isub;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        FMAObjectItem *item;
        gchar *item_label;
@@ -604,9 +604,9 @@ export_row_object( NactClipboard *clipboard, FMAObject *object, const gchar *des
                item = FMA_OBJECT_ITEM( fma_object_get_parent( object ));
        }
 
-       application = NACT_APPLICATION(
+       application = FMA_APPLICATION(
                        gtk_window_get_application( GTK_WINDOW( clipboard->private->window )));
-       updater = nact_application_get_updater( application );
+       updater = fma_application_get_updater( application );
 
        index = g_list_index( *exported, ( gconstpointer ) item );
        if( index == -1 ){
diff --git a/src/ui/nact-export-ask.c b/src/ui/nact-export-ask.c
index d88e2fc..0877b34 100644
--- a/src/ui/nact-export-ask.c
+++ b/src/ui/nact-export-ask.c
@@ -156,15 +156,15 @@ static GList *
 ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container )
 {
        NactExportAsk *window;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        GList *formats;
 
        g_return_val_if_fail( NACT_IS_EXPORT_ASK( instance ), NULL );
        window = NACT_EXPORT_ASK( instance );
 
-       application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+       updater = fma_application_get_updater( application );
        formats = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        return( formats );
diff --git a/src/ui/nact-main-window-def.h b/src/ui/nact-main-window-def.h
index 4f8d96d..2fbe039 100644
--- a/src/ui/nact-main-window-def.h
+++ b/src/ui/nact-main-window-def.h
@@ -50,10 +50,10 @@
  *
  * [main]
  *  set_log_handler()
- *  nact_application_new()
- *  nact_application_run_with_args()
+ *  fma_application_new()
+ *  fma_application_run_with_args()
  *  |
- *  +-> [NactApplication]
+ *  +-> [FMAApplication]
  *  |    on_startup()
  *  |      |
  *  |      +-> fma_updater_new()
diff --git a/src/ui/nact-main-window.c b/src/ui/nact-main-window.c
index 1ad8cc4..68d2fc9 100644
--- a/src/ui/nact-main-window.c
+++ b/src/ui/nact-main-window.c
@@ -651,11 +651,11 @@ instance_finalize( GObject *window )
  * Returns a newly allocated NactMainWindow object.
  */
 NactMainWindow *
-nact_main_window_new( NactApplication *application )
+nact_main_window_new( FMAApplication *application )
 {
        NactMainWindow *window;
 
-       g_return_val_if_fail( NACT_IS_APPLICATION( application ), NULL );
+       g_return_val_if_fail( FMA_IS_APPLICATION( application ), NULL );
 
        window = g_object_new( NACT_TYPE_MAIN_WINDOW,
                        "application", application,             /* GtkWindow property */
@@ -800,9 +800,9 @@ setup_monitor_pivot( NactMainWindow *main_window )
        priv = main_window->private;
 
        application = gtk_window_get_application( GTK_WINDOW( main_window ));
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
 
-       priv->updater = nact_application_get_updater( NACT_APPLICATION ( application ));
+       priv->updater = fma_application_get_updater( FMA_APPLICATION ( application ));
 
        priv->pivot_handler_id = g_signal_connect( priv->updater,
                        PIVOT_SIGNAL_ITEMS_CHANGED, G_CALLBACK( on_pivot_items_changed ), main_window );
@@ -1086,8 +1086,8 @@ setup_dialog_title( NactMainWindow *window )
 
        priv = window->private;
        application = gtk_window_get_application( GTK_WINDOW( window ));
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
-       title = nact_application_get_application_name( NACT_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
+       title = fma_application_get_application_name( FMA_APPLICATION( application ));
 
        if( priv->current_item ){
                label = fma_object_get_label( priv->current_item );
@@ -1266,7 +1266,7 @@ nact_main_window_quit( NactMainWindow *window )
  * this will also stop the emission of the signal (i.e. the first FALSE wins)
  */
 static gboolean
-on_base_quit_requested( NactApplication *application, NactMainWindow *window )
+on_base_quit_requested( FMAApplication *application, NactMainWindow *window )
 {
        static const gchar *thisfn = "nact_main_window_on_base_quit_requested";
        gboolean willing_to;
diff --git a/src/ui/nact-main-window.h b/src/ui/nact-main-window.h
index 2e584f1..8ca28e9 100644
--- a/src/ui/nact-main-window.h
+++ b/src/ui/nact-main-window.h
@@ -71,7 +71,7 @@ enum {
 #define MAIN_PROP_EDITABLE                                     "main-editable"
 #define MAIN_PROP_REASON                                       "main-reason"
 
-NactMainWindow  *nact_main_window_new             ( NactApplication *application );
+NactMainWindow  *nact_main_window_new             ( FMAApplication *application );
 
 NactClipboard   *nact_main_window_get_clipboard   ( const NactMainWindow *window );
 
diff --git a/src/ui/nact-menu.c b/src/ui/nact-menu.c
index 0af762a..999dd11 100644
--- a/src/ui/nact-menu.c
+++ b/src/ui/nact-menu.c
@@ -191,7 +191,7 @@ static void       on_update_sensitivities( NactMainWindow *window, void *empty )
 
 /**
  * nact_menu_app:
- * @application: the #NactApplication.
+ * @application: the #FMAApplication.
  *
  * Define the application menu and attach it to the application.
  *
@@ -200,7 +200,7 @@ static void       on_update_sensitivities( NactMainWindow *window, void *empty )
  * Quit, etc.)
  */
 void
-nact_menu_app( NactApplication *application )
+nact_menu_app( FMAApplication *application )
 {
        static const gchar *thisfn = "nact_menu_app";
        GError *error;
@@ -246,7 +246,7 @@ on_app_about( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        GtkWindow *window;
 
-       g_return_if_fail( user_data && NACT_IS_APPLICATION( user_data ));
+       g_return_if_fail( user_data && FMA_IS_APPLICATION( user_data ));
 
        window = gtk_application_get_active_window( GTK_APPLICATION( user_data ));
        g_return_if_fail( window && NACT_IS_MAIN_WINDOW( window ));
@@ -260,7 +260,7 @@ on_app_help( GSimpleAction *action, GVariant *parameter, gpointer user_data )
        static const gchar *thisfn = "nact_menu_on_app_help";
        GError *error;
 
-       g_return_if_fail( user_data && NACT_IS_APPLICATION( user_data ));
+       g_return_if_fail( user_data && FMA_IS_APPLICATION( user_data ));
 
        error = NULL;
        gtk_show_uri( NULL, "ghelp:filemanager-actions-config-tool", GDK_CURRENT_TIME, &error );
@@ -275,7 +275,7 @@ on_app_preferences( GSimpleAction *action, GVariant *parameter, gpointer user_da
 {
        GtkWindow *window;
 
-       g_return_if_fail( user_data && NACT_IS_APPLICATION( user_data ));
+       g_return_if_fail( user_data && FMA_IS_APPLICATION( user_data ));
 
        window = gtk_application_get_active_window( GTK_APPLICATION( user_data ));
        g_return_if_fail( window && NACT_IS_MAIN_WINDOW( window ));
@@ -288,7 +288,7 @@ on_app_quit( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        GtkWindow *window;
 
-       g_return_if_fail( user_data && NACT_IS_APPLICATION( user_data ));
+       g_return_if_fail( user_data && FMA_IS_APPLICATION( user_data ));
 
        window = gtk_application_get_active_window( GTK_APPLICATION( user_data ));
        g_return_if_fail( window && NACT_IS_MAIN_WINDOW( window ));
@@ -322,8 +322,8 @@ nact_menu_win( NactMainWindow *main_window )
        /* initialize the private data
         */
        application = gtk_window_get_application( GTK_WINDOW( main_window ));
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
-       sdata->updater = nact_application_get_updater( NACT_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
+       sdata->updater = fma_application_get_updater( FMA_APPLICATION( application ));
        sdata->is_level_zero_writable = fma_updater_is_level_zero_writable( sdata->updater );
        sdata->has_writable_providers =
                        ( fma_io_provider_find_writable_io_provider( FMA_PIVOT( sdata->updater )) != NULL );
diff --git a/src/ui/nact-menu.h b/src/ui/nact-menu.h
index 049da09..a250533 100644
--- a/src/ui/nact-menu.h
+++ b/src/ui/nact-menu.h
@@ -106,7 +106,7 @@ enum {
        TOOLBAR_HELP_ID,
 };
 
-void       nact_menu_app        ( NactApplication *application );
+void       nact_menu_app        ( FMAApplication *application );
 
 void       nact_menu_win        ( NactMainWindow *main_window );
 
diff --git a/src/ui/nact-preferences-editor.c b/src/ui/nact-preferences-editor.c
index 82a4580..da96c95 100644
--- a/src/ui/nact-preferences-editor.c
+++ b/src/ui/nact-preferences-editor.c
@@ -258,7 +258,7 @@ ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container
 {
        static const gchar *thisfn = "nact_preferences_editor_ioptions_list_get_options";
        GList *options;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
 
        g_return_val_if_fail( NACT_IS_PREFERENCES_EDITOR( instance ), NULL );
@@ -266,8 +266,8 @@ ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container
        options = NULL;
 
        if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesExportFormatVBox" )){
-               application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-               updater = nact_application_get_updater( application );
+               application = FMA_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
+               updater = fma_application_get_updater( application );
                options = fma_exporter_get_formats( FMA_PIVOT( updater ));
 
        } else if( container == base_window_get_widget( BASE_WINDOW( instance ), "PreferencesImportModeVBox" 
)){
diff --git a/src/ui/nact-providers-list.c b/src/ui/nact-providers-list.c
index a312c13..df12d88 100644
--- a/src/ui/nact-providers-list.c
+++ b/src/ui/nact-providers-list.c
@@ -198,7 +198,7 @@ nact_providers_list_init_view( BaseWindow *window, GtkTreeView *treeview )
 {
        static const gchar *thisfn = "nact_providers_list_init_view";
        ProvidersListData *data;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
 
        g_return_if_fail( BASE_IS_WINDOW( window ));
@@ -210,8 +210,8 @@ nact_providers_list_init_view( BaseWindow *window, GtkTreeView *treeview )
 
        data = get_providers_list_data( treeview );
        data->window = window;
-       application = NACT_APPLICATION( base_window_get_application( window ));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( window ));
+       updater = fma_application_get_updater( application );
        data->preferences_locked = fma_updater_are_preferences_locked( updater );
 
        init_view_setup_providers( treeview, window );
@@ -224,7 +224,7 @@ static void
 init_view_setup_providers( GtkTreeView *treeview, BaseWindow *window )
 {
        static const gchar *thisfn = "nact_providers_list_init_view_setup_providers";
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        GtkListStore *model;
        const GList *providers;
@@ -237,8 +237,8 @@ init_view_setup_providers( GtkTreeView *treeview, BaseWindow *window )
 
        model = GTK_LIST_STORE( gtk_tree_view_get_model( treeview ));
 
-       application = NACT_APPLICATION( base_window_get_application( window ));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( window ));
+       updater = fma_application_get_updater( application );
        providers = fma_io_provider_get_io_providers_list( FMA_PIVOT( updater ));
 
        for( iter = providers ; iter ; iter = iter->next ){
diff --git a/src/ui/nact-schemes-list.c b/src/ui/nact-schemes-list.c
index 135f19f..29738b2 100644
--- a/src/ui/nact-schemes-list.c
+++ b/src/ui/nact-schemes-list.c
@@ -200,7 +200,7 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
 {
        static const gchar *thisfn = "nact_schemes_list_init_view";
        SchemesListData *data;
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
 
        g_debug( "%s: treeview=%p, window=%p",
@@ -215,8 +215,8 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
 
        data = get_schemes_list_data( treeview );
        data->window = window;
-       application = NACT_APPLICATION( base_window_get_application( window ));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( base_window_get_application( window ));
+       updater = fma_application_get_updater( application );
        data->preferences_locked = fma_updater_are_preferences_locked( updater );
        data->editable = ( data->mode == SCHEMES_LIST_FOR_PREFERENCES && !data->preferences_locked );
        data->pf_on_sel_changed = pf;
diff --git a/src/ui/nact-sort-buttons.c b/src/ui/nact-sort-buttons.c
index ddda1e0..2ec3e11 100644
--- a/src/ui/nact-sort-buttons.c
+++ b/src/ui/nact-sort-buttons.c
@@ -206,10 +206,10 @@ nact_sort_buttons_new( NactMainWindow *window )
 
        g_return_val_if_fail( window && NACT_IS_MAIN_WINDOW( window ), NULL );
        application = gtk_window_get_application( GTK_WINDOW( window ));
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), NULL );
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), NULL );
 
        obj = g_object_new( NACT_TYPE_SORT_BUTTONS, NULL );
-       obj->private->updater = nact_application_get_updater( NACT_APPLICATION( application ));
+       obj->private->updater = fma_application_get_updater( FMA_APPLICATION( application ));
 
        initialize_buttons( obj, window );
 
diff --git a/src/ui/nact-tree-ieditable.c b/src/ui/nact-tree-ieditable.c
index 688ceee..7f5a69a 100644
--- a/src/ui/nact-tree-ieditable.c
+++ b/src/ui/nact-tree-ieditable.c
@@ -191,8 +191,8 @@ nact_tree_ieditable_initialize( NactTreeIEditable *instance, GtkTreeView *treevi
        ied->model = NACT_TREE_MODEL( gtk_tree_view_get_model( treeview ));
 
        application = gtk_window_get_application( GTK_WINDOW( main_window ));
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
-       ied->updater = nact_application_get_updater( NACT_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
+       ied->updater = fma_application_get_updater( FMA_APPLICATION( application ));
 
        /* inline label edition with F2 */
        g_signal_connect( treeview, "key-press-event", G_CALLBACK( on_key_pressed_event ), instance );
diff --git a/src/ui/nact-tree-model-dnd.c b/src/ui/nact-tree-model-dnd.c
index cce9de8..d4e3664 100644
--- a/src/ui/nact-tree-model-dnd.c
+++ b/src/ui/nact-tree-model-dnd.c
@@ -130,7 +130,7 @@ static void          drop_inside_move_dest( NactTreeModel *model, GList *rows, G
 static gboolean      drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  
*selection_data );
 static FMAObjectItem *is_dropped_already_exists( const FMAObjectItem *importing, const NactMainWindow 
*window );
 static char         *get_xds_atom_value( GdkDragContext *context );
-static gboolean      is_parent_accept_new_children( NactApplication *application, NactMainWindow *window, 
FMAObjectItem *parent );
+static gboolean      is_parent_accept_new_children( FMAApplication *application, NactMainWindow *window, 
FMAObjectItem *parent );
 static guint         target_atom_to_id( GdkAtom atom );
 
 /**
@@ -563,7 +563,7 @@ static gboolean
 drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selection_data )
 {
        static const gchar *thisfn = "nact_tree_model_dnd_inside_drag_and_drop";
-       NactApplication *application;
+       FMAApplication *application;
        FMAUpdater *updater;
        NactMainWindow *main_window;
        FMAObjectItem *parent;
@@ -579,8 +579,8 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
        gboolean relabel;
        NactTreeView *items_view;
 
-       application = NACT_APPLICATION( gtk_window_get_application( GTK_WINDOW( model->private->window )));
-       updater = nact_application_get_updater( application );
+       application = FMA_APPLICATION( gtk_window_get_application( GTK_WINDOW( model->private->window )));
+       updater = fma_application_get_updater( application );
 
        g_return_val_if_fail( NACT_IS_MAIN_WINDOW( model->private->window ), FALSE );
        main_window = NACT_MAIN_WINDOW( model->private->window );
@@ -674,7 +674,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, FMAObjectItem **paren
        drop_ok = FALSE;
        parent_dest = NULL;
        application = gtk_window_get_application( GTK_WINDOW( priv->window ));
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), FALSE );
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), FALSE );
 
        g_return_val_if_fail( priv->window && NACT_IS_MAIN_WINDOW( priv->window ), FALSE );
        main_window = NACT_MAIN_WINDOW( priv->window );
@@ -709,7 +709,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, FMAObjectItem **paren
 
        if( drop_ok ){
                drop_ok = is_parent_accept_new_children(
-                               NACT_APPLICATION( application ), main_window, parent_dest );
+                               FMA_APPLICATION( application ), main_window, parent_dest );
        }
 
        if( drop_ok && parent ){
@@ -893,8 +893,8 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
        }
 
        application = gtk_window_get_application( GTK_WINDOW( priv->window ));
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), FALSE );
-       updater = nact_application_get_updater( NACT_APPLICATION( application ));
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), FALSE );
+       updater = fma_application_get_updater( FMA_APPLICATION( application ));
 
        g_return_val_if_fail( NACT_IS_MAIN_WINDOW( priv->window ), FALSE );
        main_window = NACT_MAIN_WINDOW( priv->window );
@@ -1150,14 +1150,14 @@ get_xds_atom_value( GdkDragContext *context )
  * to register the new child
  */
 static gboolean
-is_parent_accept_new_children( NactApplication *application, NactMainWindow *window, FMAObjectItem *parent )
+is_parent_accept_new_children( FMAApplication *application, NactMainWindow *window, FMAObjectItem *parent )
 {
        gboolean accept_ok;
        FMAUpdater *updater;
        NactStatusbar *bar;
 
        accept_ok = FALSE;
-       updater = nact_application_get_updater( application );
+       updater = fma_application_get_updater( application );
        bar = nact_main_window_get_statusbar( window );
 
        /* inserting as a level zero item



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/ui/fma-application.c b/src/ui/fma-application.c
index 615de75..f6de1cc 100644
--- a/src/ui/fma-application.c
+++ b/src/ui/fma-application.c
@@ -45,7 +45,7 @@
 
 /* private instance data
  */
-struct _NactApplicationPrivate {
+struct _FMAApplicationPrivate {
        gboolean        dispose_has_run;
 
        const gchar    *application_name;       /* new: st_application_name localized version */
@@ -76,20 +76,20 @@ static GOptionEntry st_option_entries[] = {
 static GtkApplicationClass *st_parent_class = NULL;
 
 static GType    register_type( void );
-static void     class_init( NactApplicationClass *klass );
+static void     class_init( FMAApplicationClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
 static void     instance_dispose( GObject *application );
 static void     instance_finalize( GObject *application );
-static void     init_i18n( NactApplication *application );
-static gboolean init_gtk_args( NactApplication *application );
-static gboolean manage_options( NactApplication *application );
+static void     init_i18n( FMAApplication *application );
+static gboolean init_gtk_args( FMAApplication *application );
+static gboolean manage_options( FMAApplication *application );
 static void     application_startup( GApplication *application );
 static void     application_activate( GApplication *application );
 static void     application_open( GApplication *application, GFile **files, gint n_files, const gchar *hint 
);
 static void     isession_iface_init( BaseISessionInterface *iface, void *user_data );
 
 GType
-nact_application_get_type( void )
+fma_application_get_type( void )
 {
        static GType application_type = 0;
 
@@ -103,17 +103,17 @@ nact_application_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "nact_application_register_type";
+       static const gchar *thisfn = "fma_application_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NactApplicationClass ),
+               sizeof( FMAApplicationClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NactApplication ),
+               sizeof( FMAApplication ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
@@ -126,7 +126,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( GTK_TYPE_APPLICATION, "NactApplication", &info, 0 );
+       type = g_type_register_static( GTK_TYPE_APPLICATION, "FMAApplication", &info, 0 );
 
        g_type_add_interface_static( type, BASE_TYPE_ISESSION, &isession_iface_info );
 
@@ -134,9 +134,9 @@ register_type( void )
 }
 
 static void
-class_init( NactApplicationClass *klass )
+class_init( FMAApplicationClass *klass )
 {
-       static const gchar *thisfn = "nact_application_class_init";
+       static const gchar *thisfn = "fma_application_class_init";
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
@@ -153,17 +153,17 @@ class_init( NactApplicationClass *klass )
 static void
 instance_init( GTypeInstance *application, gpointer klass )
 {
-       static const gchar *thisfn = "nact_application_instance_init";
-       NactApplication *self;
+       static const gchar *thisfn = "fma_application_instance_init";
+       FMAApplication *self;
 
-       g_return_if_fail( NACT_IS_APPLICATION( application ));
+       g_return_if_fail( FMA_IS_APPLICATION( application ));
 
        g_debug( "%s: application=%p (%s), klass=%p",
                        thisfn, ( void * ) application, G_OBJECT_TYPE_NAME( application ), ( void * ) klass );
 
-       self = NACT_APPLICATION( application );
+       self = FMA_APPLICATION( application );
 
-       self->private = g_new0( NactApplicationPrivate, 1 );
+       self->private = g_new0( FMAApplicationPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
 }
@@ -171,12 +171,12 @@ instance_init( GTypeInstance *application, gpointer klass )
 static void
 instance_dispose( GObject *application )
 {
-       static const gchar *thisfn = "nact_application_instance_dispose";
-       NactApplicationPrivate *priv;
+       static const gchar *thisfn = "fma_application_instance_dispose";
+       FMAApplicationPrivate *priv;
 
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
 
-       priv = NACT_APPLICATION( application )->private;
+       priv = FMA_APPLICATION( application )->private;
 
        if( !priv->dispose_has_run ){
 
@@ -196,14 +196,14 @@ instance_dispose( GObject *application )
 static void
 instance_finalize( GObject *application )
 {
-       static const gchar *thisfn = "nact_application_instance_finalize";
-       NactApplication *self;
+       static const gchar *thisfn = "fma_application_instance_finalize";
+       FMAApplication *self;
 
-       g_return_if_fail( NACT_IS_APPLICATION( application ));
+       g_return_if_fail( FMA_IS_APPLICATION( application ));
 
        g_debug( "%s: application=%p (%s)", thisfn, ( void * ) application, G_OBJECT_TYPE_NAME( application 
));
 
-       self = NACT_APPLICATION( application );
+       self = FMA_APPLICATION( application );
 
        g_free( self->private );
 
@@ -212,17 +212,17 @@ instance_finalize( GObject *application )
 }
 
 /**
- * nact_application_new:
+ * fma_application_new:
  *
  * Returns: a newly allocated NactApplication object.
  */
-NactApplication *
-nact_application_new( void )
+FMAApplication *
+fma_application_new( void )
 {
-       NactApplication *application;
-       NactApplicationPrivate *priv;
+       FMAApplication *application;
+       FMAApplicationPrivate *priv;
 
-       application = g_object_new( NACT_TYPE_APPLICATION,
+       application = g_object_new( FMA_TYPE_APPLICATION,
                        "application-id", st_application_id,
                        NULL );
 
@@ -235,7 +235,7 @@ nact_application_new( void )
 }
 
 /**
- * nact_application_run_with_args:
+ * fma_application_run_with_args:
  * @application: this #GtkApplication -derived instance.
  * @argc:
  * @argv:
@@ -252,17 +252,17 @@ nact_application_new( void )
  * seldomly needed to override this in a derived class.
  */
 int
-nact_application_run_with_args( NactApplication *application, int argc, GStrv argv )
+fma_application_run_with_args( FMAApplication *application, int argc, GStrv argv )
 {
-       static const gchar *thisfn = "nact_application_run_with_args";
-       NactApplicationPrivate *priv;
+       static const gchar *thisfn = "fma_application_run_with_args";
+       FMAApplicationPrivate *priv;
 
        g_debug( "%s: application=%p (%s), argc=%d",
                        thisfn,
                        ( void * ) application, G_OBJECT_TYPE_NAME( application ),
                        argc );
 
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), NACT_EXIT_CODE_PROGRAM );
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), NACT_EXIT_CODE_PROGRAM );
 
        priv = application->private;
 
@@ -295,9 +295,9 @@ nact_application_run_with_args( NactApplication *application, int argc, GStrv ar
  * The program exit code will be taken from @code.
  */
 static void
-init_i18n( NactApplication *application )
+init_i18n( FMAApplication *application )
 {
-       static const gchar *thisfn = "nact_application_init_i18n";
+       static const gchar *thisfn = "fma_application_init_i18n";
 
        g_debug( "%s: application=%p", thisfn, ( void * ) application );
 
@@ -319,10 +319,10 @@ init_i18n( NactApplication *application )
  * "eat" its own arguments, and only have to handle our owns...
  */
 static gboolean
-init_gtk_args( NactApplication *application )
+init_gtk_args( FMAApplication *application )
 {
-       static const gchar *thisfn = "nact_application_init_gtk_args";
-       NactApplicationPrivate *priv;
+       static const gchar *thisfn = "fma_application_init_gtk_args";
+       FMAApplicationPrivate *priv;
        gboolean ret;
        char *parameter_string;
        GError *error;
@@ -352,9 +352,9 @@ init_gtk_args( NactApplication *application )
 }
 
 static gboolean
-manage_options( NactApplication *application )
+manage_options( FMAApplication *application )
 {
-       static const gchar *thisfn = "nact_application_manage_options";
+       static const gchar *thisfn = "fma_application_manage_options";
        gboolean ret;
 
        g_debug( "%s: application=%p", thisfn, ( void * ) application );
@@ -404,13 +404,13 @@ manage_options( NactApplication *application )
 static void
 application_startup( GApplication *application )
 {
-       static const gchar *thisfn = "nact_application_startup";
-       NactApplicationPrivate *priv;
+       static const gchar *thisfn = "fma_application_startup";
+       FMAApplicationPrivate *priv;
 
        g_debug( "%s: application=%p", thisfn, ( void * ) application );
 
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
-       priv = NACT_APPLICATION( application )->private;
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
+       priv = FMA_APPLICATION( application )->private;
 
        /* chain up to the parent class */
        if( G_APPLICATION_CLASS( st_parent_class )->startup ){
@@ -424,7 +424,7 @@ application_startup( GApplication *application )
        fma_pivot_set_loadable( FMA_PIVOT( priv->updater ), PIVOT_LOAD_ALL );
 
        /* define the application menu */
-       nact_menu_app( NACT_APPLICATION( application ));
+       nact_menu_app( FMA_APPLICATION( application ));
 }
 
 /*
@@ -455,20 +455,20 @@ application_startup( GApplication *application )
 static void
 application_activate( GApplication *application )
 {
-       static const gchar *thisfn = "nact_application_activate";
+       static const gchar *thisfn = "fma_application_activate";
        GList *windows_list;
        NactMainWindow *main_window;
 
        g_debug( "%s: application=%p", thisfn, ( void * ) application );
 
-       g_return_if_fail( application && NACT_IS_APPLICATION( application ));
+       g_return_if_fail( application && FMA_IS_APPLICATION( application ));
 
        windows_list = gtk_application_get_windows( GTK_APPLICATION( application ));
 
        /* if the application is unique, have only one main window */
        if( !st_non_unique_opt ){
                if( !g_list_length( windows_list )){
-                       main_window = nact_main_window_new( NACT_APPLICATION( application ));
+                       main_window = nact_main_window_new( FMA_APPLICATION( application ));
                        g_debug( "%s: main window instanciated at %p", thisfn, main_window );
                } else {
                        main_window = ( NactMainWindow * ) windows_list->data;
@@ -476,7 +476,7 @@ application_activate( GApplication *application )
 
        /* have as many main windows we want */
        } else {
-               main_window = nact_main_window_new( NACT_APPLICATION( application ));
+               main_window = nact_main_window_new( FMA_APPLICATION( application ));
        }
 
        g_return_if_fail( main_window && NACT_IS_MAIN_WINDOW( main_window ));
@@ -503,26 +503,26 @@ application_activate( GApplication *application )
 static void
 application_open( GApplication *application, GFile **files, gint n_files, const gchar *hint )
 {
-       static const gchar *thisfn = "nact_application_open";
+       static const gchar *thisfn = "fma_application_open";
 
        g_warning( "%s: application=%p, n_files=%d, hint=%s: unexpected run here",
                        thisfn, ( void * ) application, n_files, hint );
 }
 
 /**
- * nact_application_get_application_name:
- * @application: this #NactApplication instance.
+ * fma_application_get_application_name:
+ * @application: this #FMAApplication instance.
  *
  * Returns: the application name as a newly allocated string which should
  * be be g_free() by the caller.
  */
 gchar *
-nact_application_get_application_name( const NactApplication *application )
+fma_application_get_application_name( const FMAApplication *application )
 {
-       NactApplicationPrivate *priv;
+       FMAApplicationPrivate *priv;
        gchar *name = NULL;
 
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), NULL );
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), NULL );
 
        priv = application->private;
 
@@ -535,21 +535,21 @@ nact_application_get_application_name( const NactApplication *application )
 }
 
 /**
  * nact_application_get_updater:
  * @application: this NactApplication object.
  *
  * Returns a pointer on the #FMAUpdater object.
  *
  * The returned pointer is owned by the #NactApplication object.
  * It should not be g_free() not g_object_unref() by the caller.
  */
 FMAUpdater *
-nact_application_get_updater( const NactApplication *application )
+fma_application_get_updater( const FMAApplication *application )
 {
-       NactApplicationPrivate *priv;
+       FMAApplicationPrivate *priv;
        FMAUpdater *updater = NULL;
 
-       g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), NULL );
+       g_return_val_if_fail( application && FMA_IS_APPLICATION( application ), NULL );
 
        priv = application->private;
 
@@ -562,9 +562,9 @@ nact_application_get_updater( const NactApplication *application )
 }
 
 gboolean
-nact_application_is_willing_to_quit( const NactApplication *application )
+fma_application_is_willing_to_quit( const FMAApplication *application )
 {
-       g_return_val_if_fail( NACT_IS_APPLICATION( application ), TRUE );
+       g_return_val_if_fail( FMA_IS_APPLICATION( application ), TRUE );
        g_return_val_if_fail( BASE_IS_ISESSION( application ), TRUE );
 
        return( base_isession_is_willing_to_quit( BASE_ISESSION( application )));
@@ -573,7 +573,7 @@ nact_application_is_willing_to_quit( const NactApplication *application )
 static void
 isession_iface_init( BaseISessionInterface *iface, void *user_data )
 {
-       static const gchar *thisfn = "nact_application_isession_iface_init";
+       static const gchar *thisfn = "fma_application_isession_iface_init";
 
        g_debug( "%s: iface=%p, user_data=%p", thisfn, ( void * ) iface, ( void * ) user_data );
 }
@@ -212,17 +212,17 @@ instance_finalize( GObject *application )
  *
- * Returns: a newly allocated NactApplication object.
+ * Returns: a newly allocated FMAApplication object.
  */
@@ -535,21 +535,21 @@ nact_application_get_application_name( const NactApplication *application )
 
 /**
- * nact_application_get_updater:
- * @application: this NactApplication object.
+ * fma_application_get_updater:
+ * @application: this FMAApplication object.
  *
  * Returns a pointer on the #FMAUpdater object.
@@ -535,21 +535,21 @@ nact_application_get_application_name( const NactApplication *application )
  * Returns a pointer on the #FMAUpdater object.
  *
- * The returned pointer is owned by the #NactApplication object.
+ * The returned pointer is owned by the #FMAApplication object.
  * It should not be g_free() not g_object_unref() by the caller.
  */
diff --git a/src/ui/fma-application.h b/src/ui/fma-application.h
index e8d3274..d6104d0 100644
--- a/src/ui/fma-application.h
+++ b/src/ui/fma-application.h
@@ -27,21 +27,21 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_APPLICATION_H__
-#define __UI_NACT_APPLICATION_H__
+#ifndef __UI_FMA_APPLICATION_H__
+#define __UI_FMA_APPLICATION_H__
 
 /**
  * SECTION: nact_application
  * @short_description: #NactApplication class definition.
  * @include: nact/nact-application.h
  *
  * This is the main class for filemanager-actions-config-tool program.
  *
  * The #NactApplication object is instanciated from main() function,
  * then later #g_object_unref() after nact_application_run() has
  * returned.
  *
  * NactApplication is a non-unique application e.g. the user is able
  * to run several instance of the applications, all pointing to the
  * same actions set, potentially being able to simultaneously have
  * different views or to simultaneously act on different subsets.
@@ -53,27 +53,27 @@
 
 G_BEGIN_DECLS
 
-#define NACT_TYPE_APPLICATION                ( nact_application_get_type())
-#define NACT_APPLICATION( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_TYPE_APPLICATION, 
NactApplication ))
-#define NACT_APPLICATION_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NACT_TYPE_APPLICATION, 
NactApplicationClass ))
-#define NACT_IS_APPLICATION( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_TYPE_APPLICATION ))
-#define NACT_IS_APPLICATION_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_TYPE_APPLICATION ))
-#define NACT_APPLICATION_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_TYPE_APPLICATION, 
NactApplicationClass ))
+#define FMA_TYPE_APPLICATION                ( fma_application_get_type())
+#define FMA_APPLICATION( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_APPLICATION, 
FMAApplication ))
+#define FMA_APPLICATION_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_APPLICATION, 
FMAApplicationClass ))
+#define FMA_IS_APPLICATION( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_APPLICATION ))
+#define FMA_IS_APPLICATION_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_APPLICATION ))
+#define FMA_APPLICATION_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_APPLICATION, 
FMAApplicationClass ))
 
-typedef struct _NactApplicationPrivate       NactApplicationPrivate;
+typedef struct _FMAApplicationPrivate       FMAApplicationPrivate;
 
 typedef struct {
        /*< private >*/
        GtkApplicationClass     parent;
 }
-       NactApplicationClass;
+       FMAApplicationClass;
 
 typedef struct {
        /*< private >*/
        GtkApplication          parent;
-       NactApplicationPrivate *private;
+       FMAApplicationPrivate *private;
 }
-       NactApplication;
+       FMAApplication;
 
 /**
  * NactExitCode:
@@ -93,20 +93,20 @@ typedef enum {
 }
        NactExitCode;
 
-GType            nact_application_get_type            ( void );
+GType            fma_application_get_type            ( void );
 
-NactApplication *nact_application_new                 ( void );
+FMAApplication *fma_application_new                 ( void );
 
-int              nact_application_run_with_args       ( NactApplication *application,
+int              fma_application_run_with_args       ( FMAApplication *application,
                                                                                                              
                  int argc,
                                                                                                              
                  GStrv argv );
 
-gchar           *nact_application_get_application_name( const NactApplication *application );
+gchar           *fma_application_get_application_name( const FMAApplication *application );
 
-FMAUpdater       *nact_application_get_updater         ( const NactApplication *application );
+FMAUpdater       *fma_application_get_updater         ( const FMAApplication *application );
 
-gboolean         nact_application_is_willing_to_quit  ( const NactApplication *application );
+gboolean         fma_application_is_willing_to_quit  ( const FMAApplication *application );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_APPLICATION_H__ */
+#endif /* __UI_FMA_APPLICATION_H__ */
@@ -27,21 +27,21 @@
 
 /**
- * SECTION: nact_application
- * @short_description: #NactApplication class definition.
+ * SECTION: fma_application
+ * @short_description: #FMAApplication class definition.
  * @include: nact/nact-application.h
  *
@@ -27,21 +27,21 @@
  * This is the main class for filemanager-actions-config-tool program.
  *
- * The #NactApplication object is instanciated from main() function,
- * then later #g_object_unref() after nact_application_run() has
+ * The #FMAApplication object is instanciated from main() function,
+ * then later #g_object_unref() after fma_application_run() has
  * returned.
  *
@@ -27,21 +27,21 @@
  * returned.
  *
- * NactApplication is a non-unique application e.g. the user is able
+ * FMAApplication is a non-unique application e.g. the user is able
  * to run several instance of the applications, all pointing to the
  * same actions set, potentially being able to simultaneously have